void cone_angle(
	const int n_atoms,
	const double *coordinates,
	const double *radii,
	const int index_metal,
	double *alpha,
	double *normal,
	int *tangent_atoms,
	int *stat,
	char *errmsg);